@@ -1,14 +1,14 @@
 package Test::HTML::Tidy::Recursive;
-$Test::HTML::Tidy::Recursive::VERSION = '0.6.1';
+$Test::HTML::Tidy::Recursive::VERSION = '0.6.2';
 use strict;
 use warnings;
 use 5.008;
 
 use Test::More;
 
-use HTML::T5;
-use File::Find::Object::Rule ();
-use IO::All qw/ io /;
+use HTML::T5 qw/ TIDY_INFO TIDY_WARNING /;
+use File::Find::Object ();
+use Path::Tiny qw/ path /;
 
 use MooX qw/ late /;
 
@@ -78,7 +78,7 @@ sub check_using_tidy
 
     my $fn = $args->{filename};
 
-    $self->_tidy->parse( $fn, ( scalar io->file($fn)->slurp() ) );
+    $self->_tidy->parse( $fn, ( path($fn)->slurp_raw() ) );
 
     for my $message ( $self->_tidy->messages )
     {
@@ -112,10 +112,15 @@ sub traverse
 
     foreach my $target ( @{ $self->targets } )
     {
-        for my $fn (
-            File::Find::Object::Rule->file()->name($filename_re)->in($target) )
+        my $ffo = File::Find::Object->new( {}, $target );
+        while ( my $item = $ffo->next_obj() )
         {
-            if ( $filter->($fn) )
+            my $fn = $item->path();
+            if ( not $filter->($fn) )
+            {
+                $ffo->prune;
+            }
+            elsif ( $item->is_file() and $fn =~ $filename_re )
             {
                 $self->check_file( { filename => $fn } );
             }
@@ -131,6 +136,8 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::HTML::Tidy::Recursive - recursively check files in a directory using
@@ -138,7 +145,7 @@ HTML::T5 .
 
 =head1 VERSION
 
-version 0.6.1
+version 0.6.2
 
 =head1 SYNOPSIS
 
@@ -167,10 +174,6 @@ It was extracted from a bunch of nearly duplicate test scripts in some of
 my (= Shlomi Fish) web sites, as an attempt to avoid duplicate code and
 functionality.
 
-=head1 VERSION
-
-version 0.6.1
-
 =head1 METHODS
 
 =head2 calc_tidy
@@ -216,37 +219,10 @@ A parameter that accepts an array reference of targets as strings.
 
 L<HTML::T5> .
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2016 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/test-html-tidy-recursive/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc Test::HTML::Tidy::Recursive
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -264,14 +240,6 @@ L<https://metacpan.org/release/Test-HTML-Tidy-Recursive>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Test-HTML-Tidy-Recursive>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -280,22 +248,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-HTML-Tidy-Recursive>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Test-HTML-Tidy-Recursive>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Test-HTML-Tidy-Recursive>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -344,4 +296,25 @@ L<https://github.com/shlomif/perl-Test-HTML-Tidy-Recursive>
 
   git clone https://github.com/shlomif/perl-Test-HTML-Tidy-Recursive
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/test-html-tidy-recursive/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2016 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
